==> pollen-business-1.0.1-sources.jar: org/chorem/pollen/business/persistence/PreventRuleDAOAbstract.java <==
/* *##%
 Copyright (C) 2009 Pollen
 *##%*/
package org.chorem.pollen.business.persistence;

import java.util.List;


import java.util.Arrays;
import org.nuiton.topia.TopiaException;
import org.nuiton.topia.framework.TopiaContextImplementor;

/**
 * Implantation DAO pour l'entité PreventRule.
 * Cette classe contient une implantation de TopiaDAO a laquel elle peut
 * deleguer des traitements
 * 
 */
public abstract class PreventRuleDAOAbstract<E extends PreventRule> extends org.nuiton.topia.persistence.TopiaDAOImpl<E> implements org.nuiton.topia.persistence.TopiaDAO<E> {    

    public Class<E> getEntityClass() {
        return (Class<E>)PreventRule.class;
    }

    public void delete(E entity) throws TopiaException {
        
        super.delete(entity);
    }    
     
    /**
     * Recherche sur l'attribut scope
     */

    /**
     * Retourne le premier élément trouvé ayant comme valeur pour l'attribut
     * scope le paramètre
     * @param v la valeur que doit avoir scope
     * @return un element ou null
     */
    public E findByScope(java.lang.String v) throws TopiaException {
        E result = findByProperty("scope", v);
        return result;
    }

    /**
     * Retourne les éléments ayant comme valeur pour l'attribut
     * scope le paramètre
     * @param v la valeur que doit avoir scope
     * @return une liste
     */
    public List<E> findAllByScope(java.lang.String v) throws TopiaException {
        List<E> result = findAllByProperty("scope", v);
        return result;
    }
    /**
     * Recherche sur l'attribut sensibility
     */

    /**
     * Retourne le premier élément trouvé ayant comme valeur pour l'attribut
     * sensibility le paramètre
     * @param v la valeur que doit avoir sensibility
     * @return un element ou null
     */
    public E findBySensibility(int v) throws TopiaException {
        E result = findByProperty("sensibility", v);
        return result;
    }

    /**
     * Retourne les éléments ayant comme valeur pour l'attribut
     * sensibility le paramètre
     * @param v la valeur que doit avoir sensibility
     * @return une liste
     */
    public List<E> findAllBySensibility(int v) throws TopiaException {
        List<E> result = findAllByProperty("sensibility", v);
        return result;
    }
    /**
     * Recherche sur l'attribut repeated
     */

    /**
     * Retourne le premier élément trouvé ayant comme valeur pour l'attribut
     * repeated le paramètre
     * @param v la valeur que doit avoir repeated
     * @return un element ou null
     */
    public E findByRepeated(java.lang.Boolean v) throws TopiaException {
        E result = findByProperty("repeated", v);
        return result;
    }

    /**
     * Retourne les éléments ayant comme valeur pour l'attribut
     * repeated le paramètre
     * @param v la valeur que doit avoir repeated
     * @return une liste
     */
    public List<E> findAllByRepeated(java.lang.Boolean v) throws TopiaException {
        List<E> result = findAllByProperty("repeated", v);
        return result;
    }
    /**
     * Recherche sur l'attribut method
     */

    /**
     * Retourne le premier élément trouvé ayant comme valeur pour l'attribut
     * method le paramètre
     * @param v la valeur que doit avoir method
     * @return un element ou null
     */
    public E findByMethod(java.lang.String v) throws TopiaException {
        E result = findByProperty("method", v);
        return result;
    }

    /**
     * Retourne les éléments ayant comme valeur pour l'attribut
     * method le paramètre
     * @param v la valeur que doit avoir method
     * @return une liste
     */
    public List<E> findAllByMethod(java.lang.String v) throws TopiaException {
        List<E> result = findAllByProperty("method", v);
        return result;
    }
    /**
     * Recherche sur l'attribut poll
     */

    /**
     * Retourne le premier élément trouvé ayant comme valeur pour l'attribut
     * poll le paramètre
     * @param v la valeur que doit avoir poll
     * @return un element ou null
     */
    public E findByPoll(org.chorem.pollen.business.persistence.Poll v) throws TopiaException {
        E result = findByProperty("poll", v);
        return result;
    }

    /**
     * Retourne les éléments ayant comme valeur pour l'attribut
     * poll le paramètre
     * @param v la valeur que doit avoir poll
     * @return une liste
     */
    public List<E> findAllByPoll(org.chorem.pollen.business.persistence.Poll v) throws TopiaException {
        List<E> result = findAllByProperty("poll", v);
        return result;
    }

} // PreventRuleDAOAbstract

==> pollen-business-1.2.5-sources.jar: org/chorem/pollen/business/persistence/PreventRuleDAOAbstract.java <==
/* *##%
 Copyright (C) 2009 Pollen
 *##%*/
package org.chorem.pollen.business.persistence;

import java.util.List;


import java.util.Arrays;
import org.nuiton.topia.TopiaException;
import org.nuiton.topia.framework.TopiaContextImplementor;

/**
 * Implantation DAO pour l'entité PreventRule.
 * Cette classe contient une implantation de TopiaDAO a laquel elle peut
 * deleguer des traitements
 * 
 */
public abstract class PreventRuleDAOAbstract<E extends PreventRule> extends org.nuiton.topia.persistence.TopiaDAOImpl<E> implements org.nuiton.topia.persistence.TopiaDAO<E> {    

    public Class<E> getEntityClass() {
        return (Class<E>)PreventRule.class;
    }

    public void delete(E entity) throws TopiaException {
        
        super.delete(entity);
    }    
     
    /**
     * Recherche sur l'attribut scope
     */

    /**
     * Retourne le premier élément trouvé ayant comme valeur pour l'attribut
     * scope le paramètre
     * @param v la valeur que doit avoir scope
     * @return un element ou null
     */
    public E findByScope(java.lang.String v) throws TopiaException {
        E result = findByProperty("scope", v);
        return result;
    }

    /**
     * Retourne les éléments ayant comme valeur pour l'attribut
     * scope le paramètre
     * @param v la valeur que doit avoir scope
     * @return une liste
     */
    public List<E> findAllByScope(java.lang.String v) throws TopiaException {
        List<E> result = findAllByProperty("scope", v);
        return result;
    }
    /**
     * Recherche sur l'attribut sensibility
     */

    /**
     * Retourne le premier élément trouvé ayant comme valeur pour l'attribut
     * sensibility le paramètre
     * @param v la valeur que doit avoir sensibility
     * @return un element ou null
     */
    public E findBySensibility(java.lang.Integer v) throws TopiaException {
        E result = findByProperty("sensibility", v);
        return result;
    }

    /**
     * Retourne les éléments ayant comme valeur pour l'attribut
     * sensibility le paramètre
     * @param v la valeur que doit avoir sensibility
     * @return une liste
     */
    public List<E> findAllBySensibility(java.lang.Integer v) throws TopiaException {
        List<E> result = findAllByProperty("sensibility", v);
        return result;
    }
    /**
     * Recherche sur l'attribut repeated
     */

    /**
     * Retourne le premier élément trouvé ayant comme valeur pour l'attribut
     * repeated le paramètre
     * @param v la valeur que doit avoir repeated
     * @return un element ou null
     */
    public E findByRepeated(java.lang.Boolean v) throws TopiaException {
        E result = findByProperty("repeated", v);
        return result;
    }

    /**
     * Retourne les éléments ayant comme valeur pour l'attribut
     * repeated le paramètre
     * @param v la valeur que doit avoir repeated
     * @return une liste
     */
    public List<E> findAllByRepeated(java.lang.Boolean v) throws TopiaException {
        List<E> result = findAllByProperty("repeated", v);
        return result;
    }
    /**
     * Recherche sur l'attribut active
     */

    /**
     * Retourne le premier élément trouvé ayant comme valeur pour l'attribut
     * active le paramètre
     * @param v la valeur que doit avoir active
     * @return un element ou null
     */
    public E findByActive(java.lang.Boolean v) throws TopiaException {
        E result = findByProperty("active", v);
        return result;
    }

    /**
     * Retourne les éléments ayant comme valeur pour l'attribut
     * active le paramètre
     * @param v la valeur que doit avoir active
     * @return une liste
     */
    public List<E> findAllByActive(java.lang.Boolean v) throws TopiaException {
        List<E> result = findAllByProperty("active", v);
        return result;
    }
    /**
     * Recherche sur l'attribut oneTime
     */

    /**
     * Retourne le premier élément trouvé ayant comme valeur pour l'attribut
     * oneTime le paramètre
     * @param v la valeur que doit avoir oneTime
     * @return un element ou null
     */
    public E findByOneTime(java.lang.Boolean v) throws TopiaException {
        E result = findByProperty("oneTime", v);
        return result;
    }

    /**
     * Retourne les éléments ayant comme valeur pour l'attribut
     * oneTime le paramètre
     * @param v la valeur que doit avoir oneTime
     * @return une liste
     */
    public List<E> findAllByOneTime(java.lang.Boolean v) throws TopiaException {
        List<E> result = findAllByProperty("oneTime", v);
        return result;
    }
    /**
     * Recherche sur l'attribut method
     */

    /**
     * Retourne le premier élément trouvé ayant comme valeur pour l'attribut
     * method le paramètre
     * @param v la valeur que doit avoir method
     * @return un element ou null
     */
    public E findByMethod(java.lang.String v) throws TopiaException {
        E result = findByProperty("method", v);
        return result;
    }

    /**
     * Retourne les éléments ayant comme valeur pour l'attribut
     * method le paramètre
     * @param v la valeur que doit avoir method
     * @return une liste
     */
    public List<E> findAllByMethod(java.lang.String v) throws TopiaException {
        List<E> result = findAllByProperty("method", v);
        return result;
    }
    /**
     * Recherche sur l'attribut poll
     */

    /**
     * Retourne le premier élément trouvé ayant comme valeur pour l'attribut
     * poll le paramètre
     * @param v la valeur que doit avoir poll
     * @return un element ou null
     */
    public E findByPoll(org.chorem.pollen.business.persistence.Poll v) throws TopiaException {
        E result = findByProperty("poll", v);
        return result;
    }

    /**
     * Retourne les éléments ayant comme valeur pour l'attribut
     * poll le paramètre
     * @param v la valeur que doit avoir poll
     * @return une liste
     */
    public List<E> findAllByPoll(org.chorem.pollen.business.persistence.Poll v) throws TopiaException {
        List<E> result = findAllByProperty("poll", v);
        return result;
    }

} // PreventRuleDAOAbstract
